package com.muyu.data.source.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.data.source.domain.AccessType;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.data.source.domain.DataSource;
import com.muyu.data.source.domain.req.DataSourceQueryReq;
import com.muyu.data.source.domain.req.DataSourceSaveReq;
import com.muyu.data.source.domain.req.DataSourceEditReq;
import com.muyu.data.source.service.DataSourceService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 数据源Controller
 *
 * @author muyu
 * @date 2024-04-21
 */
@Api(tags = "数据源")
@RestController
@RequestMapping("/source")
public class DataSourceController extends BaseController {
    @Autowired
    private DataSourceService dataSourceService;

    /**
     * 查询数据源列表
     */
    @ApiOperation("获取数据源列表")
    @RequiresPermissions("dataSource:source:list")
    @GetMapping("/list")
    public Result<TableDataInfo<DataSource>> list(DataSourceQueryReq dataSourceQueryReq) {
        startPage();
        List<DataSource> list = dataSourceService.list(DataSource.queryBuild(dataSourceQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出数据源列表
     */
    @ApiOperation("导出数据源列表")
    @RequiresPermissions("dataSource:source:export")
    @Log(title = "数据源", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataSource dataSource) {
        List<DataSource> list = dataSourceService.list(dataSource);
        ExcelUtil<DataSource> util = new ExcelUtil<DataSource>(DataSource.class);
        util.exportExcel(response, list, "数据源数据");
    }

    /**
     * 获取数据源详细信息
     */
    @ApiOperation("获取数据源详细信息")
    @RequiresPermissions("dataSource:source:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<DataSource> getInfo(@PathVariable("id") Long id) {
        return Result.success(dataSourceService.getById(id));
    }

    /**
     * 新增数据源
     */
    @RequiresPermissions("dataSource:source:add")
    @Log(title = "数据源", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增数据源")
    public Result<String> add(@RequestBody DataSourceSaveReq dataSourceSaveReq) {
        return toAjax(dataSourceService.save(DataSource.saveBuild(dataSourceSaveReq)));
    }

    /**
     * 修改数据源
     */
    @RequiresPermissions("dataSource:source:edit")
    @Log(title = "数据源", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改数据源")
    public Result<String> edit(@PathVariable Long id, @RequestBody DataSourceEditReq dataSourceEditReq) {
        return toAjax(dataSourceService.updateById(DataSource.editBuild(id,dataSourceEditReq)));
    }

    /**
     * 删除数据源
     */
    @RequiresPermissions("dataSource:source:remove")
    @Log(title = "数据源", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除数据源")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(dataSourceService.removeBatchByIds(ids));
    }
    /**
     * 查询接入类型列表
     */
    @GetMapping("/findAccessType")
    public Result<List<AccessType>> findAccessType(){
        List<AccessType> accessTypeList=dataSourceService.findAccessType();
        return Result.success(accessTypeList);
    }
    @PostMapping("/testConnection")
    public Result testConnection(@RequestBody DataSourceSaveReq dataSourceSaveReq){
        return dataSourceService.testConnection(dataSourceSaveReq);
    }
}
